[PATCH] D134863: [LLVM][MC] Disable cfi-version test for aarch64-pc-windows*
Muhammad Omair Javaid via Phabricator via llvm-commits
llvm-commits at lists.llvm.org
Thu Sep 29 01:40:00 PDT 2022
omjavaid created this revision.
Herald added subscribers: kristof.beyls, emaste.
Herald added a project: All.
omjavaid requested review of this revision.
Herald added subscribers: llvm-commits, MaskRay.
Herald added a project: LLVM.
This patch disables MC/ELF/cfi-version.ll test as windows does not emit
.debug_frame needed by the test. This was previously disabled for arm64
but windows on arm uses aarch64-pc-windows* triple. Replacing arm64 with
aarch64 to accomodate windows aarch64 triple(s).
Repository:
rG LLVM Github Monorepo
https://reviews.llvm.org/D134863
Files:
llvm/test/MC/ELF/cfi-version.ll
llvm/test/lit.cfg.py
Index: llvm/test/MC/ELF/cfi-version.ll
===================================================================
--- llvm/test/MC/ELF/cfi-version.ll
+++ llvm/test/MC/ELF/cfi-version.ll
@@ -6,7 +6,7 @@
; PR46647
; XFAIL: arm64-apple
-; .debug_frame is not emitted for targeting Windows x64, arm64, or AIX.
+; .debug_frame is not emitted for targeting Windows x64, aarch64, or AIX.
; REQUIRES: debug_frame
; REQUIRES: object-emission
-------------- next part --------------
A non-text attachment was scrubbed...
Name: D134863.463797.patch
Type: text/x-patch
Size: 1145 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20220929/d4793cbb/attachment.bin>
More information about the llvm-commits
mailing list
Index: llvm/test/lit.cfg.py
===================================================================
--- llvm/test/lit.cfg.py
+++ llvm/test/lit.cfg.py
@@ -436,8 +436,8 @@
if 'hw.optional.fma: 1' in result:
config.available_features.add('fma3')
-# .debug_frame is not emitted for targeting Windows x64, arm64, or AIX.
-if not re.match(r'^(x86_64|arm64|powerpc|powerpc64).*-(windows-gnu|windows-msvc|aix)', config.target_triple):
+# .debug_frame is not emitted for targeting Windows x64, aarch64, or AIX.
+if not re.match(r'^(x86_64|aarch64|powerpc|powerpc64).*-(windows-gnu|windows-msvc|aix)', config.target_triple):
config.available_features.add('debug_frame')
if config.have_libxar: